# svnlib

This is yet another subversion wrapper for Python. The difference between this and the existing `svn` library is that this can operate on remote repositories quite well. It is meant for use with remote, infact.

One day I want to just merge this with the existing `svn` library and send a pull request.

